@@ -35,13 +35,13 @@ Neil Orley, C<< <neil.orley at oeris.fr> >>
 
 # Fixed TT : [rt.cpan.org #97596] Unimplemented in RT::Extension::HideWidgets
 #RT::System::AddRights(
-#    OerisHideWidgetBasics       => "[".__PACKAGE__."] - Hide widget 'Basics'",
-#    OerisHideWidgetPeople       => "[".__PACKAGE__."] - Hide widget 'People'",
-#    OerisHideWidgetReminders    => "[".__PACKAGE__."] - Hide widget 'Reminders'",
-#    OerisHideWidgetDates        => "[".__PACKAGE__."] - Hide widget 'Dates'",
-#    OerisHideWidgetLinks        => "[".__PACKAGE__."] - Hide widget 'Links'",
-#    OerisHideWidgetAttach       => "[".__PACKAGE__."] - Hide widget 'Attachments'",
-#    OerisHideWidgetRequestor    => "[".__PACKAGE__."] - Hide widget 'Requestor'"
+#    OerisHideWidgetBasics       => "[".__PACKAGE__."] - Hide widget 'Basics' for 'Privileged' and 'SelfService' users",
+#    OerisHideWidgetPeople       => "[".__PACKAGE__."] - Hide widget 'People' for 'Privileged' users",
+#    OerisHideWidgetReminders    => "[".__PACKAGE__."] - Hide widget 'Reminders' for 'Privileged' users",
+#    OerisHideWidgetDates        => "[".__PACKAGE__."] - Hide widget 'Dates' for 'Privileged' and 'SelfService' users",
+#    OerisHideWidgetLinks        => "[".__PACKAGE__."] - Hide widget 'Links' for 'Privileged' users",
+#    OerisHideWidgetAttach       => "[".__PACKAGE__."] - Hide widget 'Attachments' for 'Privileged' users",
+#    OerisHideWidgetRequestor    => "[".__PACKAGE__."] - Hide widget 'Requestor' for 'Privileged' users"
 #);
 
 #RT::System::AddRightCategories(
@@ -56,13 +56,13 @@ Neil Orley, C<< <neil.orley at oeris.fr> >>
 
 
 # Work only for RT 4.2.5
-'RT::System'->AddRight( General => OerisHideWidgetBasics       => "[".__PACKAGE__."] - Hide widget 'Basics'");
-'RT::System'->AddRight( General => OerisHideWidgetPeople       => "[".__PACKAGE__."] - Hide widget 'People'");
-'RT::System'->AddRight( General => OerisHideWidgetReminders    => "[".__PACKAGE__."] - Hide widget 'Reminders'"); 
-'RT::System'->AddRight( General => OerisHideWidgetDates        => "[".__PACKAGE__."] - Hide widget 'Dates'"); 
-'RT::System'->AddRight( General => OerisHideWidgetLinks        => "[".__PACKAGE__."] - Hide widget 'Links'"); 
-'RT::System'->AddRight( General => OerisHideWidgetAttach       => "[".__PACKAGE__."] - Hide widget 'Attachments'");
-'RT::System'->AddRight( General => OerisHideWidgetRequestor    => "[".__PACKAGE__."] - Hide widget 'Requestor'");
+'RT::System'->AddRight( General => OerisHideWidgetBasics       => "[".__PACKAGE__."] - Hide widget 'Basics' for 'Privileged' and 'SelfService' users");
+'RT::System'->AddRight( General => OerisHideWidgetDates        => "[".__PACKAGE__."] - Hide widget 'Dates' for 'Privileged' and 'SelfService' users"); 
+'RT::System'->AddRight( General => OerisHideWidgetPeople       => "[".__PACKAGE__."] - Hide widget 'People' for 'Privileged' users");
+'RT::System'->AddRight( General => OerisHideWidgetReminders    => "[".__PACKAGE__."] - Hide widget 'Reminders' for 'Privileged' users"); 
+'RT::System'->AddRight( General => OerisHideWidgetLinks        => "[".__PACKAGE__."] - Hide widget 'Links' for 'Privileged' users"); 
+'RT::System'->AddRight( General => OerisHideWidgetAttach       => "[".__PACKAGE__."] - Hide widget 'Attachments' for 'Privileged' users");
+'RT::System'->AddRight( General => OerisHideWidgetRequestor    => "[".__PACKAGE__."] - Hide widget 'Requestor' for 'Privileged' users");
 
 =head1 INSTALLATION
 
